==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetGatewayCertificateAuthorityPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property certificateId Identifier of the certificate entity. Must be unique in the current API Management service instance.
 * @property gatewayId Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class GetGatewayCertificateAuthorityPlainArgs(
    public val certificateId: String,
    public val gatewayId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs.builder()
            .certificateId(certificateId.let({ args0 -> args0 }))
            .gatewayId(gatewayId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGatewayCertificateAuthorityPlainArgs].
 */
@PulumiTagMarker
public class GetGatewayCertificateAuthorityPlainArgsBuilder internal constructor() {
    private var certificateId: String? = null

    private var gatewayId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Identifier of the certificate entity. Must be unique in the current API Management service instance.
     */
    @JvmName("hcmtxuoiofcallia")
    public suspend fun certificateId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.certificateId = mapped
    }

    /**
     * @param value Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
     */
    @JvmName("abrgnvrthrnobtyp")
    public suspend fun gatewayId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.gatewayId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ifnbfxbbifgpaktl")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("amkptvuwknjqpauh")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetGatewayCertificateAuthorityPlainArgs =
        GetGatewayCertificateAuthorityPlainArgs(
            certificateId = certificateId ?: throw PulumiNullFieldException("certificateId"),
            gatewayId = gatewayId ?: throw PulumiNullFieldException("gatewayId"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetGatewayCertificateAuthorityPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property certificateId Identifier of the certificate entity. Must be unique in the current API Management service instance.
 * @property gatewayId Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class GetGatewayCertificateAuthorityPlainArgs(
    public val certificateId: String,
    public val gatewayId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayCertificateAuthorityPlainArgs.builder()
            .certificateId(certificateId.let({ args0 -> args0 }))
            .gatewayId(gatewayId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGatewayCertificateAuthorityPlainArgs].
 */
@PulumiTagMarker
public class GetGatewayCertificateAuthorityPlainArgsBuilder internal constructor() {
    private var certificateId: String? = null

    private var gatewayId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Identifier of the certificate entity. Must be unique in the current API Management service instance.
     */
    @JvmName("bcekrfybbxwhoyia")
    public suspend fun certificateId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.certificateId = mapped
    }

    /**
     * @param value Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
     */
    @JvmName("pmcpivfeycxfsiqu")
    public suspend fun gatewayId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.gatewayId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("nycakklewtnjyjbt")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("lllngcugwrhplyol")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetGatewayCertificateAuthorityPlainArgs =
        GetGatewayCertificateAuthorityPlainArgs(
            certificateId = certificateId ?: throw PulumiNullFieldException("certificateId"),
            gatewayId = gatewayId ?: throw PulumiNullFieldException("gatewayId"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}
